mot.cl_routines.mapping package
===============================

Submodules
----------

mot.cl_routines.mapping.calc_dependent_params module
----------------------------------------------------

.. automodule:: mot.cl_routines.mapping.calc_dependent_params
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.calculate_model_estimates module
--------------------------------------------------------

.. automodule:: mot.cl_routines.mapping.calculate_model_estimates
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.circular_gaussian_fit module
----------------------------------------------------

.. automodule:: mot.cl_routines.mapping.circular_gaussian_fit
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.cl_function_evaluator module
----------------------------------------------------

.. automodule:: mot.cl_routines.mapping.cl_function_evaluator
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.codec_runner module
-------------------------------------------

.. automodule:: mot.cl_routines.mapping.codec_runner
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.gaussian_fit module
-------------------------------------------

.. automodule:: mot.cl_routines.mapping.gaussian_fit
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.loglikelihood_calculator module
-------------------------------------------------------

.. automodule:: mot.cl_routines.mapping.loglikelihood_calculator
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.numerical_hessian module
------------------------------------------------

.. automodule:: mot.cl_routines.mapping.numerical_hessian
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.objective_function_calculator module
------------------------------------------------------------

.. automodule:: mot.cl_routines.mapping.objective_function_calculator
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.run_procedure module
--------------------------------------------

.. automodule:: mot.cl_routines.mapping.run_procedure
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl_routines.mapping.waic_calculator module
----------------------------------------------

.. automodule:: mot.cl_routines.mapping.waic_calculator
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mot.cl_routines.mapping
    :members:
    :undoc-members:
    :show-inheritance:
